==> haskell-structured-0.1.1-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-JsSLkKQkfSiHqb0vari5wr
key:                  structured-0.1.1-JsSLkKQkfSiHqb0vari5wr
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  96b067c6f04c03ec1100391bf5ff1e13
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-JsSLkKQkfSiHqb0vari5wr
depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86 array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-KDSFpGK70SNFrMbzTIS4T1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig
    scientific-0.3.7.0-Jh9tJE2sLMpFL2bSsP8DMA
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    time-compat-1.9.6.1-KaJ6EnR2cP13bltOdWho5D transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g
    uuid-types-1.0.6-IQyEC4RLNlX9sNuZIMNyMl
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-structured-0.1.1-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-9mTKM8eLKV7sZlXKpzsjd
key:                  structured-0.1.1-9mTKM8eLKV7sZlXKpzsjd
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  495da08f273fd367a2d87529053626f2
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-9mTKM8eLKV7sZlXKpzsjd
depends:
    aeson-2.1.2.1-3xjz2RyG2JVHhJgBzFxi7A array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-LZWoqVsRU525spGmpCza2K binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    scientific-0.3.7.0-LKd2L2qVPICBdMYOyCcex4
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    time-compat-1.9.6.1-880Vipt1UYYKIVCT3LOV8F transformers-0.5.6.2
    unordered-containers-0.2.20-4cFR6FXPxn69oePlCyMUKW
    uuid-types-1.0.6-9iiZ7bUVqGV7cZb96oex9D
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
